#!/usr/bin/env python

from distutils.core import setup

setup(name='pierwszyemilki',
      version='1.0',
      description='Python Distribution Utilities',
      author='Greg Ward',
      author_email='gward@python.net',
      url='https://www.python.org/sigs/distutils-sig/',
     )